@@ -14,17 +14,18 @@ from .options import Options
 
 
 class ChartExtension(Extension):
-    tags = set(['line_chart', 'pie_chart', 'column_chart'])
+    tags = set(['line_chart', 'pie_chart', 'column_chart',
+                'bar_chart', 'area_chart'])
 
     id = itertools.count()
     _library = None
 
     def __init__(self, environment):
-            super(ChartExtension, self).__init__(environment)
+        super(ChartExtension, self).__init__(environment)
 
-            environment.extend(
-                options=dict(height='300px'),
-            )
+        environment.extend(
+            options=dict(height='300px'),
+        )
 
     def parse(self, parser):
         # parse chart name
